# (akien) This package is synced with Fedora / Josh Stone's spec.
# The aim is to work with them on a rust packaging policy we could share,
# so that we can ensure a good packaging and share the workload.


# Only x86_64 and i686 are Tier 1 platforms at this time.
# https://forge.rust-lang.org/platform-support.html
%global rust_arches x86_64 i686 i586 armv7hl aarch64 ppc64 ppc64le s390x

# The channel can be stable, beta, or nightly
%{!?channel: %global channel stable}

# To bootstrap from scratch, set the channel and date from src/stage0.txt
# e.g. 1.10.0 wants rustc: 1.9.0-2016-05-24
# or nightly wants some beta-YYYY-MM-DD
%global bootstrap_rust 1.24.0
%global bootstrap_cargo 0.25.0
%global bootstrap_channel %{bootstrap_rust}
%global bootstrap_date 2018-02-15

# Only the specified arches will use bootstrap binaries.
#global bootstrap_arches %%{rust_arches}

# Using llvm-static may be helpful as an opt-in, e.g. to aid LLVM rebases.
%bcond_with llvm_static

# We can also choose to just use Rust's bundled LLVM, in case the system LLVM
# is insufficient.  Rust currently requires LLVM 3.9+.
%if 0%{?rhel} && !0%{?epel}
%bcond_without bundled_llvm
%else
%bcond_with bundled_llvm
%endif

# LLDB only works on some architectures
%ifarch %{arm} aarch64 %{ix86} x86_64
# LLDB isn't available everywhere...
%if !0%{?rhel}
%bcond_without lldb
%else
%bcond_with lldb
%endif
%else
%bcond_with lldb
%endif



Name:           rust
Version:        1.25.0
Release:        %mkrel 1
Summary:        The Rust Programming Language
%if 0%{?mageia}
Group:          Development/Other
%endif
License:        (ASL 2.0 or MIT) and (BSD and ISC and MIT)
# ^ written as: (rust itself) and (bundled libraries)
URL:            https://www.rust-lang.org
ExclusiveArch:  %{rust_arches}

%if "%{channel}" == "stable"
%global rustc_package rustc-%{version}-src
%else
%global rustc_package rustc-%{channel}-src
%endif
Source0:        https://static.rust-lang.org/dist/%{rustc_package}.tar.xz

# https://github.com/rust-lang/rust/pull/49290
Patch1:         0001-Allow-installing-rustfmt-without-config.extended.patch

# https://github.com/rust-lang/rust/pull/49484
Patch2:         0001-Ignore-stack-probes-tests-on-powerpc-s390x-too.patch

# Get the Rust triple for any arch.
%{lua: function rust_triple(arch)
  local abi = "gnu"
  if arch == "armv7hl" then
    arch = "armv7"
    abi = "gnueabihf"
  elseif arch == "ppc64" then
    arch = "powerpc64"
  elseif arch == "ppc64le" then
    arch = "powerpc64le"
  elseif arch == "i586" then
    arch = "i686"
  end
  return arch.."-unknown-linux-"..abi
end}

%global rust_triple %{lua: print(rust_triple(rpm.expand("%{_target_cpu}")))}

%if %defined bootstrap_arches
# For each bootstrap arch, add an additional binary Source.
# Also define bootstrap_source just for the current target.
%{lua: do
  local bootstrap_arches = {}
  for arch in string.gmatch(rpm.expand("%{bootstrap_arches}"), "%S+") do
    table.insert(bootstrap_arches, arch)
  end
  local base = rpm.expand("https://static.rust-lang.org/dist/%{bootstrap_date}"
                          .."/rust-%{bootstrap_channel}")
  local target_arch = rpm.expand("%{_target_cpu}")
  for i, arch in ipairs(bootstrap_arches) do
    print(string.format("Source%d: %s-%s.tar.xz\n",
                        i, base, rust_triple(arch)))
    if arch == target_arch then
      rpm.define("bootstrap_source "..i)
    end
  end
end}
%endif

%ifarch %{bootstrap_arches}
%global bootstrap_root rust-%{bootstrap_channel}-%{rust_triple}
%global local_rust_root %{_builddir}/%{bootstrap_root}/usr
Provides:       bundled(%{name}-bootstrap) = %{bootstrap_rust}
%else
BuildRequires:  cargo >= %{bootstrap_cargo}
%if 0%{?fedora} >= 27
BuildRequires:  (%{name} >= %{bootstrap_rust} with %{name} <= %{version})
%else
BuildRequires:  %{name} >= %{bootstrap_rust}
BuildConflicts: %{name} > %{version}
%endif
%global local_rust_root %{_prefix}
%endif

BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
BuildRequires:  zlib-devel
BuildRequires:  curl

%if 0%{?rhel} && 0%{?rhel} <= 7
%global python python2
%else
%global python python3
%endif
BuildRequires:  %{python}

%if %with bundled_llvm
BuildRequires:  cmake3 >= 3.4.3
Provides:       bundled(llvm) = 6.0
%else
BuildRequires:  cmake >= 2.8.7
%if 0%{?epel}
%global llvm llvm5.0
%endif
%if %defined llvm
%global llvm_root %{_libdir}/%{llvm}
%else
%global llvm llvm
%global llvm_root %{_prefix}
%endif
BuildRequires:  %{llvm}-devel >= 3.9
%if %with llvm_static
BuildRequires:  %{llvm}-static
BuildRequires:  libffi-devel
%endif
%endif

# make check needs "ps" for src/test/run-pass/wait-forked-but-failed-child.rs
BuildRequires:  procps-ng

# debuginfo-gdb tests need gdb
BuildRequires:  gdb

# (akien) Ensure usage of rpm-mageia-setup-build with proper debuginfo macros
# Don't remove this in Mageia 6, we need to get that version from Core Updates!
%if 0%{?mageia}
BuildRequires:  rpm-mageia-setup-build >= 2.20.1
%endif

# TODO: work on unbundling these!
Provides:       bundled(hoedown) = 3.0.7
Provides:       bundled(jquery) = 2.1.4
Provides:       bundled(libbacktrace) = 6.1.0
Provides:       bundled(miniz) = 1.16~beta+r1

# Virtual provides for folks who attempt "dnf install rustc"
Provides:       rustc = %{version}-%{release}
Provides:       rustc%{?_isa} = %{version}-%{release}

# Always require our exact standard library
Requires:       %{name}-std-static%{?_isa} = %{version}-%{release}

# The C compiler is needed at runtime just for linking.  Someday rustc might
# invoke the linker directly, and then we'll only need binutils.
# https://github.com/rust-lang/rust/issues/11937
%if 0%{?mageia}
Requires:       gcc
%else
Requires:       /usr/bin/cc
%endif

# ALL Rust libraries are private, because they don't keep an ABI.
%global _privatelibs lib.*-[[:xdigit:]]*[.]so.*
%global __provides_exclude ^(%{_privatelibs})$
%global __requires_exclude ^(%{_privatelibs})$
%global __provides_exclude_from ^%{_docdir}/.*$
%global __requires_exclude_from ^%{_docdir}/.*$

# While we don't want to encourage dynamic linking to Rust shared libraries, as
# there's no stable ABI, we still need the unallocated metadata (.rustc) to
# support custom-derive plugins like #[proc_macro_derive(Foo)].  But eu-strip is
# very eager by default, so we have to limit it to -g, only debugging symbols.
%if 0%{?fedora} >= 27 || 0%{?mageia} >= 7
# Newer find-debuginfo.sh supports --keep-section, which is preferable. rhbz1465997
%global _find_debuginfo_opts --keep-section .rustc
%else
%global _find_debuginfo_opts -g
%undefine _include_minidebuginfo
%endif

# Use hardening ldflags.
%global rustflags -Clink-arg=-Wl,-z,relro,-z,now

%if %{without bundled_llvm} && "%{llvm_root}" != "%{_prefix}"
# https://github.com/rust-lang/rust/issues/40717
%global library_path $(%{llvm_root}/bin/llvm-config --libdir)
%endif

%description
Rust is a systems programming language that runs blazingly fast, prevents
segfaults, and guarantees thread safety.

This package includes the Rust compiler and documentation generator.


%package std-static
Summary:        Standard library for Rust

%description std-static
This package includes the standard libraries for building applications
written in Rust.


%package debugger-common
Summary:        Common debugger pretty printers for Rust
BuildArch:      noarch

%description debugger-common
This package includes the common functionality for %{name}-gdb and %{name}-lldb.


%package gdb
Summary:        GDB pretty printers for Rust
BuildArch:      noarch
Requires:       gdb
Requires:       %{name}-debugger-common = %{version}-%{release}

%if 0%{?mageia} == 6
# (akien) Handle moved files between our old Mageia package and this Fedora-based one
Conflicts:      rust < 1.11.0-3
%endif

%description gdb
This package includes the rust-gdb script, which allows easier debugging of Rust
programs.


%if %with lldb

%package lldb
Summary:        LLDB pretty printers for Rust

# It could be noarch, but lldb has limited availability
#BuildArch:      noarch

Requires:       lldb
%if 0%{?mageia} == 6
Requires:       python-lldb
%else
Requires:       python2-lldb
%endif
Requires:       %{name}-debugger-common = %{version}-%{release}

%description lldb
This package includes the rust-lldb script, which allows easier debugging of Rust
programs.

%endif


%package doc
Summary:        Documentation for Rust
# NOT BuildArch:      noarch
# Note, while docs are mostly noarch, some things do vary by target_arch.
# Koji will fail the build in rpmdiff if two architectures build a noarch
# subpackage differently, so instead we have to keep its arch.

%description doc
This package includes HTML documentation for the Rust programming language and
its standard library.


%package -n rustfmt-preview
Summary:        Tool to find and fix Rust formatting issues
Version:        0.3.8
Requires:       cargo

# Despite the lower version, our rustfmt-preview is newer than rustfmt-0.9.
# It's expected to stay "preview" until it's released as 1.0.
Obsoletes:      rustfmt <= 0.9.0
Provides:       rustfmt = %{version}

%description -n rustfmt-preview
A tool for formatting Rust code according to style guidelines.


%package src
Summary:        Sources for the Rust standard library
BuildArch:      noarch

%description src
This package includes source files for the Rust standard library.  It may be
useful as a reference for code completion tools in various editors.


%prep

%ifarch %{bootstrap_arches}
%setup -q -n %{bootstrap_root} -T -b %{bootstrap_source}
./install.sh --components=cargo,rustc,rust-std-%{rust_triple} \
  --prefix=%{local_rust_root} --disable-ldconfig
test -f '%{local_rust_root}/bin/cargo'
test -f '%{local_rust_root}/bin/rustc'
%endif

%setup -q -n %{rustc_package}

%patch1 -p1 -b .dist-rustfmt
%patch2 -p1 -b .ignore-ibm

%if "%{python}" == "python3"
sed -i.try-py3 -e '/try python2.7/i try python3 "$@"' ./configure
%endif

# We're disabling jemalloc, but rust-src still wants it.
# rm -rf src/jemalloc/

%if %without bundled_llvm
rm -rf src/llvm/
%endif

# We never enable emscripten.
rm -rf src/llvm-emscripten/

# extract bundled licenses for packaging
cp src/rt/hoedown/LICENSE src/rt/hoedown/LICENSE-hoedown
sed -e '/*\//q' src/libbacktrace/backtrace.h \
  >src/libbacktrace/LICENSE-libbacktrace

# This tests a problem of exponential growth, which seems to be less-reliably
# fixed when running on older LLVM and/or some arches.  Just skip it for now.
sed -i.ignore -e '1i // ignore-test may still be exponential...' \
  src/test/run-pass/issue-41696.rs

%if %{with bundled_llvm} && 0%{?epel}
mkdir -p cmake-bin
ln -s /usr/bin/cmake3 cmake-bin/cmake
%global cmake_path $PWD/cmake-bin
%endif

%if %{without bundled_llvm} && %{with llvm_static}
# Static linking to distro LLVM needs to add -lffi
# https://github.com/rust-lang/rust/issues/34486
sed -i.ffi -e '$a #[link(name = "ffi")] extern {}' \
  src/librustc_llvm/lib.rs
%endif

# The configure macro will modify some autoconf-related files, which upsets
# cargo when it tries to verify checksums in those files.  If we just truncate
# that file list, cargo won't have anything to complain about.
find src/vendor -name .cargo-checksum.json \
  -exec sed -i.uncheck -e 's/"files":{[^}]*}/"files":{ }/' '{}' '+'


%build

%{?cmake_path:export PATH=%{cmake_path}:$PATH}
%{?library_path:export LIBRARY_PATH="%{library_path}"}
%{?rustflags:export RUSTFLAGS="%{rustflags}"}

# We're going to override --libdir when configuring to get rustlib into a
# common path, but we'll fix the shared libraries during install.
%global common_libdir %{_prefix}/lib
%global rustlibdir %{common_libdir}/rustlib

%ifarch %{arm}
# full debuginfo is exhausting memory; just do libstd for now
# https://github.com/rust-lang/rust/issues/45854
%define enable_debuginfo --enable-debuginfo --enable-debuginfo-only-std --disable-debuginfo-lines
%else
%define enable_debuginfo --enable-debuginfo --disable-debuginfo-only-std --disable-debuginfo-lines
%endif

%configure --disable-option-checking \
  --libdir=%{common_libdir} \
  --build=%{rust_triple} --host=%{rust_triple} --target=%{rust_triple} \
  --local-rust-root=%{local_rust_root} \
  %{!?with_bundled_llvm: --llvm-root=%{llvm_root} --disable-codegen-tests \
    %{!?with_llvm_static: --enable-llvm-link-shared } } \
  --disable-jemalloc \
  --disable-rpath \
  %{enable_debuginfo} \
  --enable-vendor \
  --release-channel=%{channel}

%{python} ./x.py build
%{python} ./x.py build src/tools/rustfmt
%{python} ./x.py doc


%install
%{?cmake_path:export PATH=%{cmake_path}:$PATH}
%{?library_path:export LIBRARY_PATH="%{library_path}"}
%{?rustflags:export RUSTFLAGS="%{rustflags}"}

DESTDIR=%{buildroot} %{python} ./x.py install
DESTDIR=%{buildroot} %{python} ./x.py install rustfmt
DESTDIR=%{buildroot} %{python} ./x.py install src


# Make sure the shared libraries are in the proper libdir
%if "%{_libdir}" != "%{common_libdir}"
mkdir -p %{buildroot}%{_libdir}
find %{buildroot}%{common_libdir} -maxdepth 1 -type f -name '*.so' \
  -exec mv -v -t %{buildroot}%{_libdir} '{}' '+'
%endif

# The shared libraries should be executable for debuginfo extraction.
find %{buildroot}%{_libdir} -maxdepth 1 -type f -name '*.so' \
  -exec chmod -v +x '{}' '+'

# The libdir libraries are identical to those under rustlib/.  It's easier on
# library loading if we keep them in libdir, but we do need them in rustlib/
# to support dynamic linking for compiler plugins, so we'll symlink.
(cd "%{buildroot}%{rustlibdir}/%{rust_triple}/lib" &&
 find ../../../../%{_lib} -maxdepth 1 -name '*.so' |
 while read lib; do
   # make sure they're actually identical!
   cmp "$lib" "${lib##*/}"
   ln -v -f -s -t . "$lib"
 done)

# Remove installer artifacts (manifests, uninstall scripts, etc.)
find %{buildroot}%{rustlibdir} -maxdepth 1 -type f -exec rm -v '{}' '+'

# FIXME: __os_install_post will strip the rlibs
# -- should we find a way to preserve debuginfo?

# Remove unwanted documentation files (we already package them)
rm -f %{buildroot}%{_docdir}/%{name}/README.md
rm -f %{buildroot}%{_docdir}/%{name}/COPYRIGHT
rm -f %{buildroot}%{_docdir}/%{name}/LICENSE-APACHE
rm -f %{buildroot}%{_docdir}/%{name}/LICENSE-MIT
rm -f %{buildroot}%{_docdir}/%{name}/*.old

# Sanitize the HTML documentation
find %{buildroot}%{_docdir}/%{name}/html -empty -delete
find %{buildroot}%{_docdir}/%{name}/html -type f -exec chmod -x '{}' '+'

%if %without lldb
rm -f %{buildroot}%{_bindir}/rust-lldb
rm -f %{buildroot}%{rustlibdir}/etc/lldb_*.py*
%endif


%check
%{?cmake_path:export PATH=%{cmake_path}:$PATH}
%{?library_path:export LIBRARY_PATH="%{library_path}"}
%{?rustflags:export RUSTFLAGS="%{rustflags}"}

# The results are not stable on koji, so mask errors and just log it.
%{python} ./x.py test --no-fail-fast || :
%{python} ./x.py test --no-fail-fast src/tools/rustfmt || :


%if ! 0%{?mageia}
%ldconfig_scriptlets
%endif


%files
%license COPYRIGHT LICENSE-APACHE LICENSE-MIT
%license src/libbacktrace/LICENSE-libbacktrace
%license src/rt/hoedown/LICENSE-hoedown
%doc README.md
%{_bindir}/rustc
%{_bindir}/rustdoc
%{_libdir}/*.so
%{_mandir}/man1/rustc.1*
%{_mandir}/man1/rustdoc.1*
%dir %{rustlibdir}
%dir %{rustlibdir}/%{rust_triple}
%dir %{rustlibdir}/%{rust_triple}/lib
%{rustlibdir}/%{rust_triple}/lib/*.so
%{rustlibdir}/%{rust_triple}/codegen-backends/


%files std-static
%dir %{rustlibdir}
%dir %{rustlibdir}/%{rust_triple}
%dir %{rustlibdir}/%{rust_triple}/lib
%{rustlibdir}/%{rust_triple}/lib/*.rlib


%files debugger-common
%dir %{rustlibdir}
%dir %{rustlibdir}/etc
%{rustlibdir}/etc/debugger_*.py*


%files gdb
%{_bindir}/rust-gdb
%{rustlibdir}/etc/gdb_*.py*


%if %with lldb
%files lldb
%{_bindir}/rust-lldb
%{rustlibdir}/etc/lldb_*.py*
%endif


%files doc
%docdir %{_docdir}/%{name}
%dir %{_docdir}/%{name}
%dir %{_docdir}/%{name}/html
%{_docdir}/%{name}/html/*/
%{_docdir}/%{name}/html/*.html
%{_docdir}/%{name}/html/*.css
%{_docdir}/%{name}/html/*.js
%{_docdir}/%{name}/html/*.svg
%{_docdir}/%{name}/html/*.woff
%license %{_docdir}/%{name}/html/*.txt


%files -n rustfmt-preview
%{_bindir}/rustfmt
%{_bindir}/cargo-fmt
%doc src/tools/rustfmt/{README,CHANGELOG,Configurations}.md
%license src/tools/rustfmt/LICENSE-{APACHE,MIT}


%files src
%dir %{rustlibdir}
%{rustlibdir}/src


%changelog
* Thu Apr 05 2018 akien <akien> 1.25.0-1.mga6
  (not released yet)
+ Revision: 1215374
- Sync with Fedora: Thu Mar 29 2018 Josh Stone <jistone@redhat.com> - 1.25.0-1
  o Update to 1.25.0.
- Sync with Fedora: Thu Mar 01 2018 Josh Stone <jistone@redhat.com> - 1.24.1-1
  o Update to 1.24.1.
  o Backport a rebuild fix for rust#48308.
  o rhbz1546541: drop full-bootstrap; cmp libs before symlinking.
  o Backport pr46592 to fix local_rebuild bootstrapping.
  o Backport pr48362 to fix relative/absolute libdir.
  o Patch binaryen for GCC 8
- Sync with Fedora: Mon Jan 08 2018 Josh Stone <jistone@redhat.com> - 1.23.0-1
  o Update to 1.23.0.
- Enforce again usage of rpm-mageia-setup-build >= 2.20.1 to fix .rustc section stripping
- Sync with Fedora: Thu Nov 23 2017 Josh Stone <jistone@redhat.com> - 1.22.1-1
  o Update to 1.22.1.
- Sync with Fedora: Thu Oct 12 2017 Josh Stone <jistone@redhat.com> - 1.21.0-1
  o Update to 1.21.0.
- Rebuild with explicit BR on rpm-mageia-setup-build >= 2.20.1 to fix debuginfo stripping
- Rebuild against rpm-mageia-setup-2.20.1-1.mga6 with fixed _debug_install_post
- Sync with Fedora: Mon Sep 11 2017 Josh Stone <jistone@redhat.com> - 1.20.0-2
  o ABI fixes for ppc64 and s390x.
- Sync with Fedora: Thu Aug 31 2017 Josh Stone <jistone@redhat.com> - 1.20.0-1
  o Update to 1.20.0.
  o Add a rust-src subpackage.
- Sync with Fedora: Thu Jul 20 2017 Josh Stone <jistone@redhat.com> - 1.19.0-1
  o Update to 1.19.0.

* Fri Jun 09 2017 akien <akien> 1.18.0-1.mga6
+ Revision: 1107392
- Sync with Fedora: Thu Jun 08 2017 Josh Stone <jistone@redhat.com> - 1.18.0-1
  o Update to 1.18.0.
- Sync with Fedora: do not require rust-rpm-macros
- Sync with Fedora: Mon May 08 2017 Josh Stone <jistone@redhat.com> - 1.17.0-2
  o Move shared libraries back to libdir and symlink in rustlib

* Fri May 05 2017 akien <akien> 1.17.0-3.mga6
+ Revision: 1099173
- Fix stripping of .rustc due to unsupported _find_debuginfo_opts option, workaround with _find_debuginfo_dwz_opts

* Thu May 04 2017 akien <akien> 1.17.0-2.mga6
+ Revision: 1099022
- Rebuild against fixed llvm for armv7hl
- Fix rust-gdb conflicts

* Tue May 02 2017 akien <akien> 1.17.0-1.mga6
+ Revision: 1098716
- Sync with Fedora: Thu Apr 27 2017 Josh Stone <jistone@redhat.com> - 1.17.0-1
  o Update to 1.17.0.

* Sun Mar 19 2017 akien <akien> 1.16.0-1.mga6
+ Revision: 1093562
- Sync with Fedora: Fri Mar 17 2017 Josh Stone <jistone@redhat.com> - 1.16.0-2
  o Limit rust-lldb arches
- Sync with Fedora: Thu Mar 16 2017 Josh Stone <jistone@redhat.com> - 1.16.0-1
  o Update to 1.16.0.
  o Use rustbuild instead of the old makefiles.
  o Update bootstrapping to include rust-std and cargo.
  o Add a rust-lldb subpackage.

* Sat Feb 11 2017 akien <akien> 1.15.1-2.mga6
+ Revision: 1085711
- Sync with Fedora: Thu Feb 09 2017 Josh Stone <jistone@redhat.com> - 1.15.1-1
  o Update to 1.15.1.
  o Require rust-rpm-macros for new crate packaging.
  o Keep shared libraries under rustlib/, only debug-stripped.

* Sat Jan 07 2017 tmb <tmb> 1.14.0-2.mga6
+ Revision: 1080475
- rebuild with new llvm

* Fri Dec 23 2016 akien <akien> 1.14.0-1.mga6
+ Revision: 1076533
- Sync with Fedora: Thu Dec 22 2016 Josh Stone <jistone@redhat.com> - 1.14.0-1
  o Update to 1.14.0.
  o Rewrite bootstrap logic to target specific arches.

* Sat Nov 12 2016 akien <akien> 1.13.0-1.mga6
+ Revision: 1066912
- Sync with Fedora: Thu Nov 10 2016 Josh Stone <jistone@redhat.com> - 1.13.0-1
  o Update to 1.13.0.
  o Use hardening flags for linking.
  o Split the standard library into its own package
  o Centralize rustlib/ under /usr/lib/ for multilib integration.

* Fri Oct 21 2016 akien <akien> 1.12.1-1.mga6
+ Revision: 1062906
- Sync with Fedora: Thu Oct 20 2016 Josh Stone <jistone@redhat.com> - 1.12.1-1
  o Update to 1.12.1.
  o Allow building against llvm-static.
  o Add ncurses-devel for llvm-config's -ltinfo.

* Mon Oct 10 2016 akien <akien> 1.12.0-5.mga6
+ Revision: 1060082
- Sync with Fedora: Fri Oct 07 2016 Josh Stone <jistone@redhat.com> - 1.12.0-5
  o Rebuild with fixed eu-strip (rhbz1380961)
- Sync with Fedora: Thu Oct 06 2016 Josh Stone <jistone@redhat.com> - 1.12.0-3
  o Bootstrap aarch64. (Not used on Mageia yet, but kept to reduce diff)
  o Use jemalloc's MALLOC_CONF to work around #36944.
  o Apply pr36933 to really disable armv7hl NEON.
- Relax the self requirement to just version

* Mon Oct 03 2016 akien <akien> 1.12.0-4.mga6
+ Revision: 1058194
- Rebuild with system rustc

* Sun Oct 02 2016 pterjan <pterjan> 1.12.0-3.mga6
+ Revision: 1058164
- Switch to armv6, currently v7 uses neon
- make rustc load libpthread.so.0 in bootstrap mode on armv7hl, it needs it

* Sun Oct 02 2016 akien <akien> 1.12.0-2.mga6
+ Revision: 1058156
- Use a hack to pass -g to eu-strip and workaround rhbz#1380961
  The _find_debuginfo_opts macro used by Fedora seems not supported on Mageia.

* Sun Oct 02 2016 akien <akien> 1.12.0-1.mga6
+ Revision: 1058129
- Bootstrap again (we still do not have a system rust for armv7hl)
- Sync with Fedora: Sat Oct 01 2016 Josh Stone <jistone@redhat.com> - 1.12.0-2
  o Protect .rustc from rpm stripping.
- Sync with Fedora: Fri Sep 30 2016 Josh Stone <jistone@redhat.com> - 1.12.0-1
  o Update to 1.12.0.
  o Always use --local-rust-root, even for bootstrap binaries.
  o Remove the rebuild conditional - the build system now figures it out.
  o Let minidebuginfo do its thing, since metadata is no longer a note.
  o Let rust build its own compiler-rt builtins again.

* Sat Oct 01 2016 akien <akien> 1.11.0-5.mga6
+ Revision: 1058049
- Ensure build with glibc 6:2.22-21

* Sat Oct 01 2016 akien <akien> 1.11.0-4.mga6
+ Revision: 1058040
- Rebuild (still with bootstrap) for fixed glibc on armv7hl

* Fri Sep 30 2016 akien <akien> 1.11.0-3.mga6
+ Revision: 1057903
- RPM group is still mandatory for Mageia
- Handle conflict with previous package due to moved rust-gdb
- Enable bootstrap and add 1.10.0 compiler binaries for all arches
- Adjust spec file to Mageia's specifities:
  o 32-bit x86 arch is i586 and not i686, use %%ix86 macro in the logic
  o No provides on /usr/bin/ps, require procps-ng instead
  o compiler-rt version is 3.8.1
  o ldconfig is automatically called by filetriggers
- Sync package with Fedora's, effectively rewriting the whole spec
  o Rationale: our package was broken as it did not handle bootstrapping properly,
    and let the buildsystem download the rust compiler binaries from the Internet.
    Fedora has started a sane work on rust and we want to create synergiesTM.
- Changelog from the package imported from Fedora (1.11.0-3), MIT licensed
  o Sat Sep 03 2016 Josh Stone <jistone@redhat.com> - 1.11.0-3
    * Rebuild without bootstrap binaries.
  o Fri Sep 02 2016 Josh Stone <jistone@redhat.com> - 1.11.0-2
    * Bootstrap armv7hl, with backported no-neon patch.
  o Wed Aug 24 2016 Josh Stone <jistone@redhat.com> - 1.11.0-1
    * Update to 1.11.0.
    * Drop the backported patches.
    * Patch get-stage0.py to trust existing bootstrap binaries.
    * Use libclang_rt.builtins from compiler-rt, dodging llvm-static issues.
    * Use --local-rust-root to make sure the right bootstrap is used.
  o Sat Aug 13 2016 Josh Stone <jistone@redhat.com> 1.10.0-4
  o Fri Aug 12 2016 Josh Stone <jistone@redhat.com> - 1.10.0-3
    * Initial import into Fedora (#1356907), bootstrapped
    * Format license text as suggested in review.
    * Note how the tests already run in parallel.
    * Undefine _include_minidebuginfo, because it duplicates ".note.rustc".
    * Don't let checks fail the whole build.
    * Note that -doc can't be noarch, as rpmdiff doesn't allow variations.
  o Tue Jul 26 2016 Josh Stone <jistone@redhat.com> - 1.10.0-2
    * Update -doc directory ownership, and mark its licenses.
    * Package and declare licenses for libbacktrace and hoedown.
    * Set bootstrap_base as a global.
    * Explicitly require python2.
  o Thu Jul 14 2016 Josh Stone <jistone@fedoraproject.org> - 1.10.0-1
    * Initial package, bootstrapped

* Fri Sep 30 2016 shlomif <shlomif> 1.11.0-2.mga6
+ Revision: 1057836
- Rebuild to see if there's a downloading-from-the-inet bug.

* Thu Sep 08 2016 shlomif <shlomif> 1.11.0-1.mga6
+ Revision: 1050860
- Add a missing cmake BuildReq.
- New version 1.11.0. ( MGA#19282 )

* Tue Mar 15 2016 shlomif <shlomif> 1.7.0-2.mga6
+ Revision: 991033
- Remove trailing dot in summary
- New version 1.7.0

* Fri Feb 05 2016 umeabot <umeabot> 0.10-5.mga6
+ Revision: 939308
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.10-4.mga5
+ Revision: 747079
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.10-3.mga5
+ Revision: 689010
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Fri Apr 25 2014 thatsamguy <thatsamguy> 0.10-2.mga5
+ Revision: 617730
- fix libpthread.so.0 dependency issues

* Fri Apr 25 2014 thatsamguy <thatsamguy> 0.10-1.mga5
+ Revision: 617721
- update to latest release v0.10

* Sat Feb 15 2014 thatsamguy <thatsamguy> 0.9-1.mga5
+ Revision: 591692
- update to latest stable release v0.9

* Mon Oct 21 2013 umeabot <umeabot> 0.8-2.mga4
+ Revision: 541162
- Mageia 4 Mass Rebuild

* Thu Oct 10 2013 thatsamguy <thatsamguy> 0.8-1.mga4
+ Revision: 494701
- fix build error from macro in comments
- imported package rust

